@@ -12,3 +12,11 @@ from .mcdbot_error import McdbotError
 
 class ForbiddenError(McdbotError):
     NAME = "403 Forbidden - You probably don't have the required privileges to do the asked action."
+
+
+class ConflictError(McdbotError):
+    NAME = "409 Conflict"
+
+
+class InternalServerError(McdbotError):
+    NAME = "500 Internal Server Error - Please contact the administrator."
