@@ -182,7 +182,11 @@ class Mcdbot(discord.Client):
                     cmd = split.pop(0)
 
                     try:
-                        await self.commands[context][cmd].run(self, message, context, split)
+                        cmd_out = await self.commands[context][cmd].run(self, message, context, split)
+                        await message.channel.send(
+                            f"{message.author.mention} "
+                            f"{cmd_out}"
+                        )
                     except KeyError:
                         await message.channel.send(
                             f"{message.author.mention} "
